"""


Fluid Operators
***************

:func:`bake`

:func:`preset_add`

"""

import typing

def bake() -> None:

  """

  Bake fluid simulation

  """

  ...

def preset_add(name: str = '', remove_name: bool = False, remove_active: bool = False) -> None:

  """

  Add or remove a Fluid Preset

  """

  ...
