"""


GPU Select (gpu.select)
***********************

This module provides access to selection.

load_id(id)

  Set the selection ID.

  :param id:        
    Number (32-bit unsigned int).

  :type select:     
    int

"""

import typing
